caellion-python-commons: caellion.pycommons.encoding.base36.InvalidCustomCharsetLengthException Class Reference

caellion-python-commons

caellion.pycommons.encoding.base36.InvalidCustomCharsetLengthException Class Reference

This exception is raised when custom character set length . More...

Inheritance diagram for caellion.pycommons.encoding.base36.InvalidCustomCharsetLengthException:

## Detailed Description

This exception is raised when custom character set length .

Definition at line 6 of file base36.py.

The documentation for this class was generated from the following file:

- caellion/pycommons/encoding/base36.py